package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Certificate struct {
CAFile string `yaml:"ca_file"`
CertFile string `yaml:"cert_file"`
KeyFile string `yaml:"key_file"`
InsecureSkipVerify bool `yaml:"insecure_skip_verify"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.